==> igniteui-react-16.16.2.tgz: package/esm5/lib/CalendarBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CalendarBaseSelection_$type } from "./CalendarBaseSelection";
import { CalendarBaseWeekStart_$type } from "./CalendarBaseWeekStart";
/**
 * @hidden
 */
var CalendarBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalendarBase, _super);
    function CalendarBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.h = null;
        return _this;
    }
    Object.defineProperty(CalendarBase.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "nativeElement", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e.d = this.h;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "c", {
        get: function () {
            var ret_ = this.f.c("selection");
            ret_ = enumGetBox(CalendarBaseSelection_$type, EnumUtil.getEnumValue(CalendarBaseSelection_$type, EnumUtil.parse(CalendarBaseSelection_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(CalendarBaseSelection_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarBaseSelection_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("selection", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "g", {
        get: function () {
            var ret_ = this.f.c("showWeekNumbers");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("showWeekNumbers", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "d", {
        get: function () {
            var ret_ = this.f.c("weekStart");
            ret_ = enumGetBox(CalendarBaseWeekStart_$type, EnumUtil.getEnumValue(CalendarBaseWeekStart_$type, EnumUtil.parse(CalendarBaseWeekStart_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(CalendarBaseWeekStart_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarBaseWeekStart_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("weekStart", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "j", {
        get: function () {
            var ret_ = this.f.c("locale");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("locale", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "a", {
        get: function () {
            var ret_ = this.f.c("disabledDates");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("disabledDates", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "b", {
        get: function () {
            var ret_ = this.f.c("specialDates");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("specialDates", value_);
        },
        enumerable: false,
        configurable: true
    });
    CalendarBase.$t = markType(CalendarBase, 'CalendarBase', BaseElement.$);
    return CalendarBase;
}(BaseElement));
export { CalendarBase };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/CalendarBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CalendarBaseSelection_$type } from "./CalendarBaseSelection";
import { CalendarBaseWeekStart_$type } from "./CalendarBaseWeekStart";
import { DateRangeDescriptor } from "./DateRangeDescriptor";
/**
 * @hidden
 */
var CalendarBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalendarBase, _super);
    function CalendarBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.h = null;
        return _this;
    }
    Object.defineProperty(CalendarBase.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "nativeElement", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e.o = this.h;
        },
        enumerable: false,
        configurable: true
    });
    CalendarBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(CalendarBase.prototype, "c", {
        get: function () {
            var ret_ = this.f.n("selection");
            ret_ = enumGetBox(CalendarBaseSelection_$type, EnumUtil.getEnumValue(CalendarBaseSelection_$type, this.f.f(CalendarBaseSelection_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarBaseSelection_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarBaseSelection_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("selection", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "g", {
        get: function () {
            var ret_ = this.f.n("showWeekNumbers");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("showWeekNumbers", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "d", {
        get: function () {
            var ret_ = this.f.n("weekStart");
            ret_ = enumGetBox(CalendarBaseWeekStart_$type, EnumUtil.getEnumValue(CalendarBaseWeekStart_$type, this.f.f(CalendarBaseWeekStart_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarBaseWeekStart_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarBaseWeekStart_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("weekStart", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "j", {
        get: function () {
            var ret_ = this.f.n("locale");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("locale", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "a", {
        get: function () {
            var ret_ = this.f.m("disabledDates", function (a) { return new DateRangeDescriptor(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("disabledDates", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CalendarBase.prototype, "b", {
        get: function () {
            var ret_ = this.f.m("specialDates", function (a) { return new DateRangeDescriptor(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("specialDates", value_);
        },
        enumerable: false,
        configurable: true
    });
    CalendarBase.$t = markType(CalendarBase, 'CalendarBase', BaseElement.$);
    return CalendarBase;
}(BaseElement));
export { CalendarBase };
